#!/usr/bin/env python
import matplotlib.pyplot as pyplot
import mcidasx
import netCDF4
import numpy
import os
import sys

os.environ['PATH']   = "%s:%s/mcidas/bin:/home/mcidas/bin" % (os.environ['HOME'],os.environ['PATH'])
os.environ['MCPATH'] = "%s/mcidas/data:/home/mcidas/data" % os.environ['HOME']

mc = mcidasx.mcenv()
mc.logon('xxx xxx')
# substitute your accounting for 'xxx xxx' above

result1 = mc.dataloc('ADD AMET09 geoarc.ssec.wisc.edu')
if result1.retcode != 0:
    sys.exit(result1.stdout)

mc.dsserve('ADD N/A NCDF 1 9999 TYPE=IMAGE')

msg_ndvi_bands = [1, 2]

imgcopy_string = 'AMET09/FD N/A.{band} SIZE=SAME BAND={band} MAG=-8 DAY=2011/08/31 TIME=12 UNIT=REFL'
for band in msg_ndvi_bands:
    imgcopy_result = mc.imgcopy(imgcopy_string.format(band=band))
    print(imgcopy_result.stdout)

try:
    # open the NetCDF files
    redBand = netCDF4.Dataset('%s/mcidas/data/A0001.nc' % os.environ['HOME'], 'r')
    nirBand = netCDF4.Dataset('%s/mcidas/data/A0002.nc' % os.environ['HOME'], 'r')

    redData = numpy.array(redBand.variables['data'][0])
    nirData = numpy.array(nirBand.variables['data'][0])

    check = numpy.logical_and(redData != 0, nirData != 0)
    ndvi = numpy.where(check, (nirData - redData) / (nirData + redData), 0)

    pyplot.imshow(ndvi, cmap=pyplot.get_cmap('PRGn'), vmin=-1, vmax=1)
    pyplot.savefig('ndvi.png')
    pyplot.show()

except:
    sys.exit('An error occurred.')